@@ -16,16 +16,27 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.beyondcorp_appconnections_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -33,10 +44,6 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.beyondcorp_appconnections_v1.services.app_connections_service import (
-    pagers,
-)
-from google.cloud.beyondcorp_appconnections_v1.types import app_connections_service
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -44,16 +51,26 @@ from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AppConnectionsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AppConnectionsServiceGrpcAsyncIOTransport
+
+from google.cloud.beyondcorp_appconnections_v1.services.app_connections_service import (
+    pagers,
+)
+from google.cloud.beyondcorp_appconnections_v1.types import app_connections_service
+
 from .client import AppConnectionsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, AppConnectionsServiceTransport
+from .transports.grpc_asyncio import AppConnectionsServiceGrpcAsyncIOTransport
 
 
 class AppConnectionsServiceAsyncClient:
-    """API Overview: The ``beyondcorp.googleapis.com`` service implements the Google
+    """API Overview:
+
+    The ``beyondcorp.googleapis.com`` service implements the Google
     Cloud BeyondCorp API.
 
-    Data Model: The AppConnectionsService exposes the following resources:
+    Data Model:
+
+    The AppConnectionsService exposes the following resources:
 
     -  AppConnections, named as follows:
        ``projects/{project_id}/locations/{location_id}/appConnections/{app_connection_id}``.
@@ -192,9 +209,9 @@ class AppConnectionsServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AppConnectionsServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the app connections service client.
@@ -238,11 +255,13 @@ class AppConnectionsServiceAsyncClient:
 
     async def list_app_connections(
         self,
-        request: Union[app_connections_service.ListAppConnectionsRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.ListAppConnectionsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAppConnectionsAsyncPager:
         r"""Lists AppConnections in a given project and location.
@@ -275,7 +294,7 @@ class AppConnectionsServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.ListAppConnectionsRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.ListAppConnectionsRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.ListAppConnections.
             parent (:class:`str`):
@@ -354,11 +373,13 @@ class AppConnectionsServiceAsyncClient:
 
     async def get_app_connection(
         self,
-        request: Union[app_connections_service.GetAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.GetAppConnectionRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> app_connections_service.AppConnection:
         r"""Gets details of a single AppConnection.
@@ -390,7 +411,7 @@ class AppConnectionsServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.GetAppConnectionRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.GetAppConnectionRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.GetAppConnection.
             name (:class:`str`):
@@ -462,13 +483,15 @@ class AppConnectionsServiceAsyncClient:
 
     async def create_app_connection(
         self,
-        request: Union[app_connections_service.CreateAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.CreateAppConnectionRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        app_connection: app_connections_service.AppConnection = None,
-        app_connection_id: str = None,
+        parent: Optional[str] = None,
+        app_connection: Optional[app_connections_service.AppConnection] = None,
+        app_connection_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new AppConnection in a given project and
@@ -506,13 +529,13 @@ class AppConnectionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.CreateAppConnectionRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.CreateAppConnectionRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.CreateAppConnection.
             parent (:class:`str`):
@@ -615,12 +638,14 @@ class AppConnectionsServiceAsyncClient:
 
     async def update_app_connection(
         self,
-        request: Union[app_connections_service.UpdateAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.UpdateAppConnectionRequest, dict]
+        ] = None,
         *,
-        app_connection: app_connections_service.AppConnection = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        app_connection: Optional[app_connections_service.AppConnection] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single AppConnection.
@@ -656,13 +681,13 @@ class AppConnectionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.UpdateAppConnectionRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.UpdateAppConnectionRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.UpdateAppConnection.
             app_connection (:class:`google.cloud.beyondcorp_appconnections_v1.types.AppConnection`):
@@ -761,11 +786,13 @@ class AppConnectionsServiceAsyncClient:
 
     async def delete_app_connection(
         self,
-        request: Union[app_connections_service.DeleteAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.DeleteAppConnectionRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single AppConnection.
@@ -795,13 +822,13 @@ class AppConnectionsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.DeleteAppConnectionRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.DeleteAppConnectionRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.DeleteAppConnection.
             name (:class:`str`):
@@ -885,13 +912,13 @@ class AppConnectionsServiceAsyncClient:
 
     async def resolve_app_connections(
         self,
-        request: Union[
-            app_connections_service.ResolveAppConnectionsRequest, dict
+        request: Optional[
+            Union[app_connections_service.ResolveAppConnectionsRequest, dict]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ResolveAppConnectionsAsyncPager:
         r"""Resolves AppConnections details for a given
@@ -927,7 +954,7 @@ class AppConnectionsServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.beyondcorp_appconnections_v1.types.ResolveAppConnectionsRequest, dict]):
+            request (Optional[Union[google.cloud.beyondcorp_appconnections_v1.types.ResolveAppConnectionsRequest, dict]]):
                 The request object. Request message for
                 BeyondCorp.ResolveAppConnections.
             parent (:class:`str`):
@@ -1006,10 +1033,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -1060,10 +1087,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1114,10 +1141,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -1169,10 +1196,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -1223,10 +1250,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM access control policy on the specified function.
@@ -1343,10 +1370,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM access control policy for a function.
@@ -1464,10 +1491,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests the specified IAM permissions against the IAM access control
@@ -1523,10 +1550,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1577,10 +1604,10 @@ class AppConnectionsServiceAsyncClient:
 
     async def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -1636,14 +1663,9 @@ class AppConnectionsServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-beyondcorp-appconnections",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AppConnectionsServiceAsyncClient",)
