@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.beyondcorp_appconnections_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,10 +48,6 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.beyondcorp_appconnections_v1.services.app_connections_service import (
-    pagers,
-)
-from google.cloud.beyondcorp_appconnections_v1.types import app_connections_service
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -47,7 +55,13 @@ from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AppConnectionsServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.beyondcorp_appconnections_v1.services.app_connections_service import (
+    pagers,
+)
+from google.cloud.beyondcorp_appconnections_v1.types import app_connections_service
+
+from .transports.base import DEFAULT_CLIENT_INFO, AppConnectionsServiceTransport
 from .transports.grpc import AppConnectionsServiceGrpcTransport
 from .transports.grpc_asyncio import AppConnectionsServiceGrpcAsyncIOTransport
 from .transports.rest import AppConnectionsServiceRestTransport
@@ -70,7 +84,7 @@ class AppConnectionsServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[AppConnectionsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -91,10 +105,14 @@ class AppConnectionsServiceClientMeta(type):
 
 
 class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
-    """API Overview: The ``beyondcorp.googleapis.com`` service implements the Google
+    """API Overview:
+
+    The ``beyondcorp.googleapis.com`` service implements the Google
     Cloud BeyondCorp API.
 
-    Data Model: The AppConnectionsService exposes the following resources:
+    Data Model:
+
+    The AppConnectionsService exposes the following resources:
 
     -  AppConnections, named as follows:
        ``projects/{project_id}/locations/{location_id}/appConnections/{app_connection_id}``.
@@ -401,8 +419,8 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, AppConnectionsServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, AppConnectionsServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the app connections service client.
@@ -416,10 +434,7 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
             transport (Union[str, AppConnectionsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-                NOTE: "rest" transport functionality is currently in a
-                beta state (preview). We welcome your feedback via an
-                issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -449,6 +464,7 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -501,11 +517,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def list_app_connections(
         self,
-        request: Union[app_connections_service.ListAppConnectionsRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.ListAppConnectionsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAppConnectionsPager:
         r"""Lists AppConnections in a given project and location.
@@ -617,11 +635,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def get_app_connection(
         self,
-        request: Union[app_connections_service.GetAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.GetAppConnectionRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> app_connections_service.AppConnection:
         r"""Gets details of a single AppConnection.
@@ -725,13 +745,15 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def create_app_connection(
         self,
-        request: Union[app_connections_service.CreateAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.CreateAppConnectionRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        app_connection: app_connections_service.AppConnection = None,
-        app_connection_id: str = None,
+        parent: Optional[str] = None,
+        app_connection: Optional[app_connections_service.AppConnection] = None,
+        app_connection_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new AppConnection in a given project and
@@ -878,12 +900,14 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def update_app_connection(
         self,
-        request: Union[app_connections_service.UpdateAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.UpdateAppConnectionRequest, dict]
+        ] = None,
         *,
-        app_connection: app_connections_service.AppConnection = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        app_connection: Optional[app_connections_service.AppConnection] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates the parameters of a single AppConnection.
@@ -1024,11 +1048,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def delete_app_connection(
         self,
-        request: Union[app_connections_service.DeleteAppConnectionRequest, dict] = None,
+        request: Optional[
+            Union[app_connections_service.DeleteAppConnectionRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single AppConnection.
@@ -1148,13 +1174,13 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def resolve_app_connections(
         self,
-        request: Union[
-            app_connections_service.ResolveAppConnectionsRequest, dict
+        request: Optional[
+            Union[app_connections_service.ResolveAppConnectionsRequest, dict]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ResolveAppConnectionsPager:
         r"""Resolves AppConnections details for a given
@@ -1284,10 +1310,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -1338,10 +1364,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1392,10 +1418,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -1447,10 +1473,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -1501,10 +1527,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM access control policy on the specified function.
@@ -1621,10 +1647,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM access control policy for a function.
@@ -1742,10 +1768,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests the specified IAM permissions against the IAM access control
@@ -1801,10 +1827,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1855,10 +1881,10 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
 
     def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -1908,14 +1934,9 @@ class AppConnectionsServiceClient(metaclass=AppConnectionsServiceClientMeta):
         return response
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-beyondcorp-appconnections",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("AppConnectionsServiceClient",)
